@@ -20,7 +20,7 @@ if not pycharm_launch:
     sys.path.insert(1, str(myroot / "Node Subsystem"))
     sys.path.insert(1, str(myroot / "xUML"))
 
-from XumlClassDiagram import XumlClassDiagram
+from flatland.xUML.XumlClassDiagram import XumlClassDiagram
 
 # Configure the expected parameters and actions for the argparse module
 def parse(cl_input):
